@@ -95,7 +95,7 @@ Diff <- function(player1, player2, formula = NULL, id = "..", data = NULL,
         ## - however as only allowing (1|..) just consider player id for now
 
         saturated <- qr(na.omit(X))$rank == qr(na.omit(cbind(D, X)))$rank && !idterm
-        X <- X[, -1, drop = FALSE]
+        if (all(X[,1] == 0)) X <- X[, -1, drop = FALSE]
         attr(X, "assign") <- attr(X1, "assign")[-1]
     }
 
